summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/include')
-rw-r--r--src/include/report/event_config.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/include/report/event_config.h b/src/include/report/event_config.h
index 8dcfb9f6..5b3532a1 100644
--- a/src/include/report/event_config.h
+++ b/src/include/report/event_config.h
@@ -64,10 +64,11 @@ void free_event_option(event_option_t *p);
//structure to hold the option data
typedef struct
{
- char *screen_name; //ui friendly name of the event "Bugzilla" "RedHat Support Uploader"
- //char *title; //window title - not used right now, maybe the "name" is enough?
- //char *action;//action description to show in gui like: Upload report to the Red Hat bugzilla"
- char *description; // "Report to ...."/"Save to file"
+ char *screen_name; //ui friendly name of the event: "Bugzilla" "RedHat Support Upload"
+ //char *title; //window title - not used right now, maybe the "name" is enough?
+ //char *action; //action description to show in gui like: Upload report to the Red Hat bugzilla"
+ char *description; // "Report to..."/"Save to file". Should be one sentence, not long
+ char *long_descr; // Long(er) explanation, if needed
GList *options;
} event_config_t;